@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.cpp,v 1.29 2004/12/05 21:52:31 vkurland Exp $
+  $Id: FirewallDialog.cpp,v 1.29.4.1 2005/10/25 06:11:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -264,13 +264,24 @@ void FirewallDialog::openFWDialog()
 
     if (obj->getStr("version").empty()) saveVersion();
 
-    QWidget *w = DialogFactory::createFWDialog(this,obj);
-    if (w==NULL)   return;   // some dialogs may not be implemented yet
+    try
+    {
+        QWidget *w = DialogFactory::createFWDialog(this,obj);
+        if (w==NULL)   return;   // some dialogs may not be implemented yet
+        QDialog *d=dynamic_cast<QDialog*>(w);
+        assert(d!=NULL);
 
-    QDialog *d=dynamic_cast<QDialog*>(w);
-    assert(d!=NULL);
-
-    d->exec();   // modal dialog, dialog saves data into the object
+        d->exec();   // modal dialog, dialog saves data into the object
+    }
+    catch (FWException &ex)
+    {
+        QMessageBox::critical(
+            this,"Firewall Builder",
+            tr("FWBuilder API error: %1").arg(ex.toString().c_str()),
+            tr("&Continue"), QString::null,QString::null,
+            0, 1 );
+        return;
+    }
 }
 
 
@@ -278,13 +289,24 @@ void FirewallDialog::openOSDialog()
 {
     if (apply->isEnabled()) applyChanges();
 
-    QWidget *w = DialogFactory::createOSDialog(this,obj);
-    if (w==NULL)   return;   // some dialogs may not be implemented yet
+    try
+    {
+        QWidget *w = DialogFactory::createOSDialog(this,obj);
+        if (w==NULL)   return;   // some dialogs may not be implemented yet
+        QDialog *d=dynamic_cast<QDialog*>(w);
+        assert(d!=NULL);
 
-    QDialog *d=dynamic_cast<QDialog*>(w);
-    assert(d!=NULL);
-
-    d->exec();   // modal dialog, dialog saves data into the object
+        d->exec();   // modal dialog, dialog saves data into the object
+    }
+    catch (FWException &ex)
+    {
+        QMessageBox::critical(
+            this,"Firewall Builder",
+            tr("FWBuilder API error: %1").arg(ex.toString().c_str()),
+            tr("&Continue"), QString::null,QString::null,
+            0, 1 );
+        return;
+    }
 }
 
 /* ObjectEditor class connects its slot to this signal and does all
