@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iptAdvancedDialog.cpp,v 1.22.4.1 2005/09/04 20:49:14 vkurland Exp $
+  $Id: iptAdvancedDialog.cpp,v 1.22.4.2 2005/11/06 02:52:49 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -82,7 +82,7 @@ iptAdvancedDialog::iptAdvancedDialog(QWidget *parent,FWObject *o)
     logLevel->insertStringList( getScreenNames(slm));
     data.registerOption( logLevel,   fwoptions,  "log_level", slm); 
     
-    data.registerOption(useULOG,    fwoptions, "useULOG"         );
+    data.registerOption(useULOG,    fwoptions, "use_ULOG"        );
     data.registerOption(cprange,    fwoptions, "ulog_cprange"    );
     data.registerOption(qthreshold, fwoptions, "ulog_qthreshold" );
     data.registerOption(nlgroup,    fwoptions, "ulog_nlgroup"    );
