@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp,v 1.89.4.2 2005/09/04 21:54:55 vkurland Exp $
+  $Id: main.cpp,v 1.89.4.3 2005/10/25 06:11:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -77,6 +77,10 @@
 #  include <direct.h>
 #endif
 
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#endif
+
 #ifdef HAVE_PTY_H
 #include <pty.h>
 #endif
