@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.cpp,v 1.25 2005/06/11 20:49:46 vkurland Exp $
+  $Id: PolicyCompiler_ipt.cpp,v 1.25.4.1 2005/10/27 06:31:38 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1191,15 +1191,14 @@ bool PolicyCompiler_ipt::splitIfSrcNegAndFw::processNext()
                 nsrc->addRef(*m);
             tmp_queue.push_back(r);
 
-            rule->setStr("ipt_chain","FORWARD");
+//            rule->setStr("ipt_chain","FORWARD");
             nsrc=rule->getSrc();
-            nsrc->clearChildren();  // do not use reset, it clears negation flag
+            nsrc->reset();   // resets negation flag
             for (list<FWObject*>::iterator m=notFwLikes.begin(); m!=notFwLikes.end(); ++m) 
                 nsrc->addRef(*m);
-            /* after clearChildren RE has zero children and since it does not
-             * have 'any network' as a child, isAny() returns false
-             */
-            if (nsrc->isAny() || nsrc->size()==0) nsrc->setNeg(false);
+            if (!nsrc->isAny()) nsrc->setNeg(true);
+            FWOptions  *ruleopt = rule->getOptionsObject();
+            ruleopt->setBool("firewall_is_part_of_any_and_networks",false);  // so we do not put this rule in OUTPUT chain later
             tmp_queue.push_back(rule);
             return true;
         }
@@ -1269,13 +1268,17 @@ bool PolicyCompiler_ipt::splitIfDstNegAndFw::processNext()
                 ndst->addRef(*m);
             tmp_queue.push_back(r);
 
-            rule->setStr("ipt_chain","FORWARD");
+            // the second rule goes into FORWARD chain, but if source
+            // is (or contains) firewall, we may also need OUTPUT chain
+
+//            rule->setStr("ipt_chain","FORWARD");
             ndst=rule->getDst();
-            ndst->clearChildren();  // do not use reset, it clears negation flag
+            ndst->reset();   // resets negation flag
             for (list<FWObject*>::iterator m=notFwLikes.begin(); m!=notFwLikes.end(); ++m) 
                 ndst->addRef(*m);
-
-            if (ndst->isAny() || ndst->size()==0) ndst->setNeg(false);
+            if (!ndst->isAny()) ndst->setNeg(true);
+            FWOptions  *ruleopt = rule->getOptionsObject();
+            ruleopt->setBool("firewall_is_part_of_any_and_networks",false);  // so we do not put this rule in INPUT chain later
             tmp_queue.push_back(rule);
             return true;
         }
